# yamm

[![PyPI version](https://badge.fury.io/py/yamm.svg)](https://badge.fury.io/py/yamm)
[![Build Status](https://travis-ci.org/timpauli/yamm.svg?branch=master)](https://travis-ci.org/timpauli/yamm)
[![Coverage Status](https://coveralls.io/repos/github/timpauli/yamm/badge.svg?branch=master)](https://coveralls.io/github/timpauli/yamm?branch=master)

yet another markov module
